summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>1995-11-06 21:11:47 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>1995-11-06 21:11:47 +0000
commita7907d088cd0d07cdc37c3464833376f03a7e3ef (patch)
tree8cac63f6a9969a46756be8d9abe1fb8d05476b02
parent6f9ab36e2d02933f496e5de2596a237ebf9650e4 (diff)
complete ufs -> ffs change (From John Kohl; PR #1403)
-rw-r--r--sbin/fsck/main.c6
-rw-r--r--sbin/fsck_ffs/main.c6
-rw-r--r--sbin/mount_ffs/mount_ffs.c6
-rw-r--r--sbin/mountd/mountd.c10
-rw-r--r--sbin/quotacheck/quotacheck.c4
5 files changed, 16 insertions, 16 deletions
diff --git a/sbin/fsck/main.c b/sbin/fsck/main.c
index 128005b6fe5..d5cd4107794 100644
--- a/sbin/fsck/main.c
+++ b/sbin/fsck/main.c
@@ -1,4 +1,4 @@
-/* $NetBSD: main.c,v 1.18 1995/07/12 03:39:53 cgd Exp $ */
+/* $NetBSD: main.c,v 1.18.2.1 1995/11/01 00:06:18 jtc Exp $ */
/*
* Copyright (c) 1980, 1986, 1993
@@ -43,7 +43,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)main.c 8.2 (Berkeley) 1/23/94";
#else
-static char rcsid[] = "$NetBSD: main.c,v 1.18 1995/07/12 03:39:53 cgd Exp $";
+static char rcsid[] = "$NetBSD: main.c,v 1.18.2.1 1995/11/01 00:06:18 jtc Exp $";
#endif
#endif /* not lint */
@@ -330,7 +330,7 @@ checkfilesys(filesys, mntpt, auxdata, child)
args.export.ex_flags = 0;
args.export.ex_root = 0;
flags |= MNT_UPDATE | MNT_RELOAD;
- ret = mount(MOUNT_UFS, "/", flags, &args);
+ ret = mount(MOUNT_FFS, "/", flags, &args);
if (ret == 0)
return(0);
}
diff --git a/sbin/fsck_ffs/main.c b/sbin/fsck_ffs/main.c
index 128005b6fe5..d5cd4107794 100644
--- a/sbin/fsck_ffs/main.c
+++ b/sbin/fsck_ffs/main.c
@@ -1,4 +1,4 @@
-/* $NetBSD: main.c,v 1.18 1995/07/12 03:39:53 cgd Exp $ */
+/* $NetBSD: main.c,v 1.18.2.1 1995/11/01 00:06:18 jtc Exp $ */
/*
* Copyright (c) 1980, 1986, 1993
@@ -43,7 +43,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)main.c 8.2 (Berkeley) 1/23/94";
#else
-static char rcsid[] = "$NetBSD: main.c,v 1.18 1995/07/12 03:39:53 cgd Exp $";
+static char rcsid[] = "$NetBSD: main.c,v 1.18.2.1 1995/11/01 00:06:18 jtc Exp $";
#endif
#endif /* not lint */
@@ -330,7 +330,7 @@ checkfilesys(filesys, mntpt, auxdata, child)
args.export.ex_flags = 0;
args.export.ex_root = 0;
flags |= MNT_UPDATE | MNT_RELOAD;
- ret = mount(MOUNT_UFS, "/", flags, &args);
+ ret = mount(MOUNT_FFS, "/", flags, &args);
if (ret == 0)
return(0);
}
diff --git a/sbin/mount_ffs/mount_ffs.c b/sbin/mount_ffs/mount_ffs.c
index 043f8b3535e..1ba1743f34f 100644
--- a/sbin/mount_ffs/mount_ffs.c
+++ b/sbin/mount_ffs/mount_ffs.c
@@ -1,4 +1,4 @@
-/* $NetBSD: mount_ffs.c,v 1.1 1995/07/12 03:46:50 cgd Exp $ */
+/* $NetBSD: mount_ffs.c,v 1.1.2.1 1995/11/01 00:06:20 jtc Exp $ */
/*-
* Copyright (c) 1993, 1994
@@ -43,7 +43,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)mount_ufs.c 8.2 (Berkeley) 3/27/94";
#else
-static char rcsid[] = "$NetBSD: mount_ffs.c,v 1.1 1995/07/12 03:46:50 cgd Exp $";
+static char rcsid[] = "$NetBSD: mount_ffs.c,v 1.1.2.1 1995/11/01 00:06:20 jtc Exp $";
#endif
#endif /* not lint */
@@ -107,7 +107,7 @@ main(argc, argv)
else
args.export.ex_flags = 0;
- if (mount(MOUNT_UFS, fs_name, mntflags, &args) < 0) {
+ if (mount(MOUNT_FFS, fs_name, mntflags, &args) < 0) {
switch (errno) {
case EMFILE:
errcause = "mount table full";
diff --git a/sbin/quotacheck/quotacheck.c b/sbin/quotacheck/quotacheck.c
index 09ea3fb633d..6d308c52866 100644
--- a/sbin/quotacheck/quotacheck.c
+++ b/sbin/quotacheck/quotacheck.c
@@ -1,4 +1,4 @@
-/* $NetBSD: quotacheck.c,v 1.10 1995/03/18 14:59:22 cgd Exp $ */
+/* $NetBSD: quotacheck.c,v 1.10.2.1 1995/11/01 00:32:51 jtc Exp $ */
/*
* Copyright (c) 1980, 1990, 1993
@@ -46,7 +46,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)quotacheck.c 8.3 (Berkeley) 1/29/94";
#else
-static char rcsid[] = "$NetBSD: quotacheck.c,v 1.10 1995/03/18 14:59:22 cgd Exp $";
+static char rcsid[] = "$NetBSD: quotacheck.c,v 1.10.2.1 1995/11/01 00:32:51 jtc Exp $";
#endif
#endif /* not lint */
diff --git a/sbin/mountd/mountd.c b/sbin/mountd/mountd.c
index 8d668271ee5..c4b4afff932 100644
--- a/sbin/mountd/mountd.c
+++ b/sbin/mountd/mountd.c
@@ -1,4 +1,4 @@
-/* $NetBSD: mountd.c,v 1.27 1995/08/19 16:08:05 chopps Exp $ */
+/* $NetBSD: mountd.c,v 1.27.2.1 1995/11/01 00:06:22 jtc Exp $ */
/*
* Copyright (c) 1989, 1993
@@ -46,7 +46,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)mountd.c 8.8 (Berkeley) 2/20/94";
#else
-static char rcsid[] = "$NetBSD: mountd.c,v 1.27 1995/08/19 16:08:05 chopps Exp $";
+static char rcsid[] = "$NetBSD: mountd.c,v 1.27.2.1 1995/11/01 00:06:22 jtc Exp $";
#endif
#endif /* not lint */
@@ -636,7 +636,7 @@ get_exportlist()
* And delete exports that are in the kernel for all local
* file systems.
* XXX: Should know how to handle all local exportable file systems
* instead of just MOUNT_UFS.
*/
num = getmntinfo(&fsp, MNT_NOWAIT);
for (i = 0; i < num; i++) {
@@ -649,7 +649,7 @@ get_exportlist()
} targs;
if (!strncmp(fsp->f_fstypename, MOUNT_MFS, MFSNAMELEN) ||
- !strncmp(fsp->f_fstypename, MOUNT_UFS, MFSNAMELEN) ||
+ !strncmp(fsp->f_fstypename, MOUNT_FFS, MFSNAMELEN) ||
!strncmp(fsp->f_fstypename, MOUNT_MSDOS, MFSNAMELEN) ||
!strncmp(fsp->f_fstypename, MOUNT_ADOSFS, MFSNAMELEN) ||
!strncmp(fsp->f_fstypename, MOUNT_CD9660, MFSNAMELEN)) {
@@ -1533,7 +1533,7 @@ do_mount(ep, grp, exflags, anoncrp, dirp, dirplen, fsb)
* Maybe I should just use the fsb->f_mntonname path instead
* of looping back up the dirp to the mount point??
* Also, needs to know how to export all types of local
* exportable file systems and not just MOUNT_UFS.
*/
while (mount(fsb->f_fstypename, dirp,
fsb->f_flags | MNT_UPDATE, (caddr_t)&args) < 0) {
@@ -636,7 +636,7 @@ get_exportlist()
* file systems.
* XXX: Should know how to handle all local exportable file systems
- * instead of just MOUNT_UFS.
+ * instead of just MOUNT_FFS.
*/
num = getmntinfo(&fsp, MNT_NOWAIT);
@@ -1533,7 +1533,7 @@ do_mount(ep, grp, exflags, anoncrp, dirp, dirplen, fsb)
* of looping back up the dirp to the mount point??
* Also, needs to know how to export all types of local
- * exportable file systems and not just MOUNT_UFS.
+ * exportable file systems and not just MOUNT_FFS.
*/
while (mount(fsb->f_fstypename, dirp,